@@ -42,13 +42,13 @@ ScreenChooserDialog::ScreenChooserDialog(const QMap<quint32, ScreenCastPortalOut
         widgetItem->setData(Qt::UserRole, it.key());
         if (it.value().outputType == ScreenCastPortalOutput::Laptop) {
             widgetItem->setIcon(QIcon::fromTheme("computer-laptop"));
-            widgetItem->setText(i18n("Laptop screen\nModel: %1").arg(it.value().model));
+            widgetItem->setText(i18n("Laptop screen\nModel: %1", it.value().model));
         } else if (it.value().outputType == ScreenCastPortalOutput::Monitor) {
             widgetItem->setIcon(QIcon::fromTheme("video-display"));
-            widgetItem->setText(i18n("Manufacturer: %1\nModel: %2").arg(it.value().manufacturer).arg(it.value().model));
+            widgetItem->setText(i18n("Manufacturer: %1\nModel: %2", it.value().manufacturer, it.value().model));
         } else {
             widgetItem->setIcon(QIcon::fromTheme("video-television"));
-            widgetItem->setText(i18n("Manufacturer: %1\nModel: %2").arg(it.value().manufacturer).arg(it.value().model));
+            widgetItem->setText(i18n("Manufacturer: %1\nModel: %2", it.value().manufacturer, it.value().model));
         }
     }
 
